@@ -1,9 +1,9 @@
 
 
 
-### Copyright (C) 2001-2005 Deepayan Sarkar <Deepayan.Sarkar@R-project.org> and 
+### Copyright (C) 2001-2006 Deepayan Sarkar <Deepayan.Sarkar@R-project.org> 
 ###
-### This file is part of the lattice library for R.
+### This file is part of the lattice package for R.
 ### It is made available under the terms of the GNU General Public
 ### License, version 2, or at your option, any later version,
 ### incorporated herein by reference.
@@ -144,6 +144,7 @@ panel.segments <- function(...) lsegments(...)
 panel.text <- function(...) ltext(...)
 panel.arrows <- function(...) larrows(...)
 panel.rect <- function(...) lrect(...)
+panel.polygon <- function(...) lpolygon(...)
 
 
 
@@ -158,6 +159,33 @@ panel.rect <- function(...) lrect(...)
 
 
 
+lpolygon <-
+    function(x, y = NULL,
+             ## density = NULL,
+             ## angle = 45,
+             border = "black",
+             col = "transparent",
+             ## lty = NULL,
+             ...) 
+{
+    if (is.logical(border))
+        border <-
+            if (border) "black"
+            else "transparent"
+    xy <- xy.coords(x, y)
+    if (with(xy, sum(!is.na(x) & !is.na(y))) > 0)
+        grid.polygon(x = xy$x,
+                     y = xy$y,
+                     default.units = "native",
+                     gp =
+                     gpar(fill = col,
+                          col = border,
+                          ...))
+}
+
+
+
+
 lsegments <-
     function(x0 = NULL, y0 = NULL, x1, y1,
              x2 = NULL, y2 = NULL,
@@ -300,12 +328,13 @@ ltext <-
                    fontfamily = fontfamily,
                    fontface = chooseFace(fontface, font),
                    cex = cex),
-              just = c(if (adj[1] == 0) "left"
-              else if (adj[1] == 1) c("right")
-              else "centre",
-              if (adj[2] == 0) "bottom"
-              else if (adj[2] == 1) c("top")
-              else "centre"),
+              just = adj,
+##               just = c(if (adj[1] == 0) "left"
+##               else if (adj[1] == 1) c("right")
+##               else "centre",
+##               if (adj[2] == 0) "bottom"
+##               else if (adj[2] == 1) c("top")
+##               else "centre"),
               rot = srt)
 }
 
